@@ -59,7 +59,9 @@ class Statement(metaclass=PoolMeta):
 
     def _group_key(self, line):
         key = super(Statement, self)._group_key(line)
-        return key + (('payment', line.payment),)
+        if hasattr(line, 'payment'):
+            key += (('payment', line.payment),)
+        return key
 
 
 class StatementLine(metaclass=PoolMeta):
@@ -77,13 +79,13 @@ class StatementLine(metaclass=PoolMeta):
     payment_group = fields.Many2One(
         'account.payment.group', "Payment Group",
         domain=[
-            ('company', '=', Eval('_parent_statement', {}).get('company', -1)),
+            ('company', '=', Eval('company', -1)),
             ],
         states={
             'invisible': Bool(Eval('payment')) | Bool(Eval('invoice')),
             'readonly': Eval('statement_state') != 'draft',
             },
-        depends=['statement_state'])
+        depends=['company', 'statement_state'])
 
     @classmethod
     def __setup__(cls):
